@@ -92,7 +92,7 @@ class Client:
         if response is not None:
             if response.status_code == 200:
                 status = response.json()
-                return status
+                return json.dumps(status)
             elif response.status_code == 404:
                 return None
             else:
@@ -121,8 +121,8 @@ class Client:
             raise exceptions.CakeworkError("Something unexpected happened")
         if response is not None:
             if response.status_code == 200:
-                result = response.text
-                return result
+                result = response.json()
+                return json.loads(result)
             elif response.status_code == 404:
                 return None
             else:
